==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/business_activity_links.dart <==
part of keyclic_sdk_api.api;

class BusinessActivityLinks {
  BusinessActivityLinks({
    this.self,
    this.schema,
    this.image,
  });

  BusinessActivityLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    self = BusinessActivityLinksSelf.fromJson(json['self']);
    schema = BusinessActivityLinksSchema.fromJson(json['schema']);
    image = BusinessActivityLinksImage.fromJson(json['image']);
  }

  BusinessActivityLinksSelf self;

  BusinessActivityLinksSchema schema;

  BusinessActivityLinksImage image;

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is BusinessActivityLinks && runtimeType == other.runtimeType;
  }

  @override
  int get hashCode => 0;

  Map<String, dynamic> toJson() {
    return {
      'self': self,
      'schema': schema,
      'image': image,
    };
  }

  @override
  String toString() {
    return 'BusinessActivityLinks[self=$self, schema=$schema, image=$image, ]';
  }

  static List<BusinessActivityLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? List<BusinessActivityLinks>()
        : json.map((value) => BusinessActivityLinks.fromJson(value)).toList();
  }

  static Map<String, BusinessActivityLinks> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, BusinessActivityLinks>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = BusinessActivityLinks.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/business_activity_links.dart <==
part of keyclic_sdk_api.api;

class BusinessActivityLinks {
  BusinessActivityLinks({
    this.image,
    this.schema,
    this.self,
    this.thumbnail,
  });

  BusinessActivityLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    image = BusinessActivityLinksImage.fromJson(json['image']);
    schema = BusinessActivityLinksSchema.fromJson(json['schema']);
    self = BusinessActivityLinksSelf.fromJson(json['self']);
    thumbnail = BusinessActivityLinksThumbnail.fromJson(json['thumbnail']);
  }

  BusinessActivityLinksImage image;

  BusinessActivityLinksSchema schema;

  BusinessActivityLinksSelf self;

  BusinessActivityLinksThumbnail thumbnail;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is BusinessActivityLinks &&
        runtimeType == other.runtimeType &&
        image == other.image &&
        schema == other.schema &&
        self == other.self &&
        thumbnail == other.thumbnail;
  }

  /// By default hashCode return reference
  @override
  int get hashCode =>
      0 ^ image.hashCode ^ schema.hashCode ^ self.hashCode ^ thumbnail.hashCode;

  static List<BusinessActivityLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? <BusinessActivityLinks>[]
        : json.map((value) => BusinessActivityLinks.fromJson(value)).toList();
  }

  static Map<String, BusinessActivityLinks> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, BusinessActivityLinks>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = BusinessActivityLinks.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'image': image,
      'schema': schema,
      'self': self,
      'thumbnail': thumbnail,
    };
  }

  @override
  String toString() {
    return 'BusinessActivityLinks[image=$image, schema=$schema, self=$self, thumbnail=$thumbnail, ]';
  }
}
